@@ -33,9 +33,10 @@
 #  define ANALITZA_DEPRECATED_NO_EXPORT ANALITZA_NO_EXPORT ANALITZA_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define ANALITZA_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef ANALITZA_NO_DEPRECATED
+#    define ANALITZA_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
