@@ -33,9 +33,10 @@
 #  define ANALITZAPLOT_DEPRECATED_NO_EXPORT ANALITZAPLOT_NO_EXPORT ANALITZAPLOT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define ANALITZAPLOT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef ANALITZAPLOT_NO_DEPRECATED
+#    define ANALITZAPLOT_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
